@@ -3,6 +3,7 @@
 
 Actions associated with `git` and Git repos.
 """
+from . import __gitlab as gitlab
 from .__git import add, checkout, clone, commit, current_branch, pull, push
 
 __all__ = [
@@ -13,4 +14,5 @@ __all__ = [
     "current_branch",
     "pull",
     "push",
+    "gitlab",
 ]
